@@ -17,33 +17,27 @@
 import { connect } from 'react-redux';
 import { defineMessages, FormattedMessage, injectIntl } from 'react-intl';
 import ImmutablePropTypes from 'react-immutable-proptypes';
-import { Link } from 'react-router-dom';
+import { ModalHeader, ModalTitle, ModalFooter } from 'react-bootstrap';
 import PropTypes from 'prop-types';
 import React from 'react';
 
-import {
-  allPreDeploymentValidationsSuccessful
-} from '../../selectors/validations';
+import { allPreDeploymentValidationsSuccessful } from '../../selectors/validations';
 import DeploymentConfirmation from './DeploymentConfirmation';
 import DeploymentProgress from './DeploymentProgress';
 import DeploymentSuccess from './DeploymentSuccess';
 import DeploymentFailure from './DeploymentFailure';
-import { getCurrentPlan } from '../../selectors/plans';
+import { getCurrentPlan, getCurrentPlanName } from '../../selectors/plans';
 import {
   getCurrentStack,
   getCurrentStackDeploymentProgress
 } from '../../selectors/stacks';
+import { getEnvironmentConfigurationSummary } from '../../selectors/environmentConfiguration';
+import { Loader } from '../ui/Loader';
 import {
-  getEnvironmentConfigurationSummary
-} from '../../selectors/environmentConfiguration';
-import Loader from '../ui/Loader';
-import {
-  ModalPanelBackdrop,
-  ModalPanel,
-  ModalPanelHeader,
-  ModalPanelBody,
-  ModalPanelFooter
-} from '../ui/ModalPanel';
+  CloseModalButton,
+  CloseModalXButton,
+  RoutedModalPanel
+} from '../ui/Modals';
 import PlanActions from '../../actions/PlansActions';
 import { stackStates } from '../../constants/StacksConstants';
 import StacksActions from '../../actions/StacksActions';
@@ -69,6 +63,7 @@ class DeploymentDetail extends React.Component {
     const {
       allPreDeploymentValidationsSuccessful,
       currentPlan,
+      currentPlanName,
       currentStack,
       currentStackDeploymentProgress,
       currentStackResources,
@@ -76,8 +71,7 @@ class DeploymentDetail extends React.Component {
       deployPlan,
       environmentConfigurationSummary,
       fetchStackResources,
-      runPreDeploymentValidations,
-      stacksLoaded
+      runPreDeploymentValidations
     } = this.props;
 
     if (
@@ -85,19 +79,13 @@ class DeploymentDetail extends React.Component {
       currentStack.stack_status === stackStates.DELETE_COMPLETE
     ) {
       return (
-        <Loader
-          loaded={stacksLoaded}
-          content={this.props.intl.formatMessage(messages.loadingStacksLoader)}
-          height={40}
-        >
-          <DeploymentConfirmation
-            allValidationsSuccessful={allPreDeploymentValidationsSuccessful}
-            currentPlan={currentPlan}
-            deployPlan={deployPlan}
-            environmentSummary={environmentConfigurationSummary}
-            runPreDeploymentValidations={runPreDeploymentValidations}
-          />
-        </Loader>
+        <DeploymentConfirmation
+          allValidationsSuccessful={allPreDeploymentValidationsSuccessful}
+          currentPlan={currentPlan}
+          deployPlan={deployPlan}
+          environmentSummary={environmentConfigurationSummary}
+          runPreDeploymentValidations={runPreDeploymentValidations}
+        />
       );
     } else if (currentStack.stack_status.match(/PROGRESS/)) {
       return (
@@ -124,42 +112,44 @@ class DeploymentDetail extends React.Component {
           stack={currentStack}
           stackResources={currentStackResources}
           stackResourcesLoaded={currentStackResourcesLoaded}
-          planName={currentPlan.name}
+          planName={currentPlanName}
         />
       );
     }
   }
 
   render() {
+    const {
+      currentPlanName,
+      intl: { formatMessage },
+      stacksLoaded
+    } = this.props;
     return (
-      <div>
-        <ModalPanelBackdrop />
-        <ModalPanel>
-          <ModalPanelHeader>
-            <Link to="/deployment-plan" type="button" className="close">
-              <span aria-hidden="true" className="pficon pficon-close" />
-            </Link>
-            <h2 className="modal-title">
-              <FormattedMessage
-                {...messages.modalTitle}
-                values={{ planName: this.props.currentPlan.name }}
-              />
-            </h2>
-          </ModalPanelHeader>
-          <ModalPanelBody>
-            {this.renderStatus()}
-          </ModalPanelBody>
-          <ModalPanelFooter>
-            <Link
-              to="/deployment-plan"
-              type="button"
-              className="btn btn-default"
-            >
-              <FormattedMessage {...messages.close} />
-            </Link>
-          </ModalPanelFooter>
-        </ModalPanel>
-      </div>
+      <RoutedModalPanel redirectPath={`/plans/${currentPlanName}`}>
+        <ModalHeader>
+          <CloseModalXButton />
+          <ModalTitle>
+            <FormattedMessage
+              {...messages.modalTitle}
+              values={{ planName: currentPlanName }}
+            />
+          </ModalTitle>
+        </ModalHeader>
+        <Loader
+          loaded={stacksLoaded}
+          className="flex-container"
+          content={formatMessage(messages.loadingStacksLoader)}
+          componentProps={{ className: 'flex-container' }}
+          height={40}
+        >
+          {this.renderStatus()}
+        </Loader>
+        <ModalFooter>
+          <CloseModalButton>
+            <FormattedMessage {...messages.close} />
+          </CloseModalButton>
+        </ModalFooter>
+      </RoutedModalPanel>
     );
   }
 }
@@ -167,6 +157,7 @@ class DeploymentDetail extends React.Component {
 DeploymentDetail.propTypes = {
   allPreDeploymentValidationsSuccessful: PropTypes.bool.isRequired,
   currentPlan: ImmutablePropTypes.record.isRequired,
+  currentPlanName: PropTypes.string.isRequired,
   currentStack: ImmutablePropTypes.record,
   currentStackDeploymentProgress: PropTypes.number.isRequired,
   currentStackResources: ImmutablePropTypes.map,
@@ -185,6 +176,7 @@ const mapStateToProps = state => {
       state
     ),
     currentPlan: getCurrentPlan(state),
+    currentPlanName: getCurrentPlanName(state),
     currentStack: getCurrentStack(state),
     currentStackDeploymentProgress: getCurrentStackDeploymentProgress(state),
     currentStackResources: state.stacks.resources,
